====================================
Challenge 4 Simple Linear Regression
====================================


.. image:: https://img.shields.io/pypi/v/challenge_4_simple_linear_regression.svg
        :target: https://pypi.python.org/pypi/challenge_4_simple_linear_regression

.. image:: https://img.shields.io/travis/zedki7/challenge_4_simple_linear_regression.svg
        :target: https://travis-ci.com/zedki7/challenge_4_simple_linear_regression

.. image:: https://readthedocs.org/projects/challenge-4-simple-linear-regression/badge/?version=latest
        :target: https://challenge-4-simple-linear-regression.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Challenge 4 Simple Linear Regression Model


* Free software: MIT license
* Documentation: https://challenge-4-simple-linear-regression.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
